package javax.swing.plaf.basic;

import javax.swing.plaf.UIResource;
import javax.swing.text.StyleConstants;
import sun.swing.SwingUtilities2;
import javax.swing.text.Style;
import javax.swing.text.html.StyleSheet;
import javax.swing.text.Document;
import javax.swing.text.html.HTMLDocument;
import javax.swing.text.StyledDocument;
import java.awt.Color;
import java.awt.Font;
import javax.swing.SwingUtilities;
import java.beans.PropertyChangeEvent;
import javax.swing.Action;
import javax.swing.TransferHandler;
import javax.swing.plaf.ActionMapUIResource;
import javax.swing.ActionMap;
import javax.swing.JEditorPane;
import javax.swing.text.EditorKit;
import javax.swing.text.JTextComponent;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;

public class BasicEditorPaneUI extends BasicTextUI
{
    private static final String FONT_ATTRIBUTE_KEY = "FONT_ATTRIBUTE_KEY";
    
    public static ComponentUI createUI(JComponent component) {
        return new BasicEditorPaneUI();
    }
    
    public BasicEditorPaneUI() {
    }
    
    @Override
    protected String getPropertyPrefix() {
        return "EditorPane";
    }
    
    @Override
    public void installUI(JComponent component) {
        super.installUI(component);
        this.updateDisplayProperties(component.getFont(), component.getForeground());
    }
    
    @Override
    public void uninstallUI(JComponent component) {
        this.cleanDisplayProperties();
        super.uninstallUI(component);
    }
    
    @Override
    public EditorKit getEditorKit(JTextComponent textComponent) {
        return ((JEditorPane)this.getComponent()).getEditorKit();
    }
    
    @Override
    ActionMap getActionMap() {
        ActionMapUIResource actionMapUIResource = new ActionMapUIResource();
        actionMapUIResource.put("requestFocus", new BasicTextUI.FocusAction());
        EditorKit editorKit = this.getEditorKit(this.getComponent());
        if (editorKit != null) {
            Action[] actions = editorKit.getActions();
            if (actions != null) {
                this.addActions(actionMapUIResource, actions);
            }
        }
        actionMapUIResource.put(TransferHandler.getCutAction().getValue("Name"), TransferHandler.getCutAction());
        actionMapUIResource.put(TransferHandler.getCopyAction().getValue("Name"), TransferHandler.getCopyAction());
        actionMapUIResource.put(TransferHandler.getPasteAction().getValue("Name"), TransferHandler.getPasteAction());
        return actionMapUIResource;
    }
    
    @Override
    protected void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        super.propertyChange(propertyChangeEvent);
        String propertyName = propertyChangeEvent.getPropertyName();
        if ("editorKit".equals(propertyName)) {
            ActionMap uiActionMap = SwingUtilities.getUIActionMap(this.getComponent());
            if (uiActionMap != null) {
                Object oldValue = propertyChangeEvent.getOldValue();
                if ((oldValue instanceof EditorKit)) {
                    Action[] actions = ((EditorKit)oldValue).getActions();
                    if (actions != null) {
                        this.removeActions(uiActionMap, actions);
                    }
                }
                Object newValue = propertyChangeEvent.getNewValue();
                if ((newValue instanceof EditorKit)) {
                    Action[] actions2 = ((EditorKit)newValue).getActions();
                    if (actions2 != null) {
                        this.addActions(uiActionMap, actions2);
                    }
                }
            }
            this.updateFocusTraversalKeys();
        }
        else if ("editable".equals(propertyName)) {
            this.updateFocusTraversalKeys();
        }
        else if ("foreground".equals(propertyName) || "font".equals(propertyName) || "document".equals(propertyName) || "JEditorPane.w3cLengthUnits".equals(propertyName) || "JEditorPane.honorDisplayProperties".equals(propertyName)) {
            JTextComponent component = this.getComponent();
            this.updateDisplayProperties(component.getFont(), component.getForeground());
            if ("JEditorPane.w3cLengthUnits".equals(propertyName) || "JEditorPane.honorDisplayProperties".equals(propertyName)) {
                this.modelChanged();
            }
            if ("foreground".equals(propertyName)) {
                Object clientProperty = component.getClientProperty("JEditorPane.honorDisplayProperties");
                boolean booleanValue = false;
                if ((clientProperty instanceof Boolean)) {
                    booleanValue = (boolean)clientProperty;
                }
                if (!(booleanValue == 0)) {
                    this.modelChanged();
                }
            }
        }
    }
    
    void removeActions(ActionMap actionMap, Action[] array) {
        for (int length = array.length, i = 0; i < length; ++i) {
            actionMap.remove(array[i].getValue("Name"));
        }
    }
    
    void addActions(ActionMap actionMap, Action[] array) {
        for (Action action : array) {
            actionMap.put(action.getValue("Name"), action);
        }
    }
    
    void updateDisplayProperties(Font font, Color color) {
        JTextComponent component = this.getComponent();
        Object clientProperty = component.getClientProperty("JEditorPane.honorDisplayProperties");
        boolean booleanValue = false;
        Object clientProperty2 = component.getClientProperty("JEditorPane.w3cLengthUnits");
        boolean booleanValue2 = false;
        if ((clientProperty instanceof Boolean)) {
            booleanValue = (boolean)clientProperty;
        }
        if ((clientProperty2 instanceof Boolean)) {
            booleanValue2 = (boolean)clientProperty2;
        }
        if (this instanceof BasicTextPaneUI || booleanValue) {
            Document document = this.getComponent().getDocument();
            if ((document instanceof StyledDocument)) {
                if (document instanceof HTMLDocument && booleanValue) {
                    this.updateCSS(font, color);
                }
                else {
                    this.updateStyle(font, color);
                }
            }
        }
        else {
            this.cleanDisplayProperties();
        }
        if (!(booleanValue2 == 0)) {
            Document document3 = this.getComponent().getDocument();
            if ((document3 instanceof HTMLDocument)) {
                ((HTMLDocument)document3).getStyleSheet().addRule("W3C_LENGTH_UNITS_ENABLE");
            }
        }
        else {
            Document document2 = this.getComponent().getDocument();
            if ((document2 instanceof HTMLDocument)) {
                ((HTMLDocument)document2).getStyleSheet().addRule("W3C_LENGTH_UNITS_DISABLE");
            }
        }
    }
    
    void cleanDisplayProperties() {
        Document document = this.getComponent().getDocument();
        if ((document instanceof HTMLDocument)) {
            StyleSheet styleSheet = ((HTMLDocument)document).getStyleSheet();
            StyleSheet[] styleSheets = styleSheet.getStyleSheets();
            if (styleSheets != null) {
                int length = styleSheets.length;
                int i = 0;
                while (i < length) {
                    StyleSheet ss = styleSheets[i];
                    if ((ss instanceof BasicEditorPaneUI.StyleSheetUIResource)) {
                        styleSheet.removeStyleSheet(ss);
                        styleSheet.addRule("BASE_SIZE_DISABLE");
                        break;
                    }
                    ++i;
                }
            }
            Style style = ((StyledDocument)document).getStyle("default");
            if (style.getAttribute("FONT_ATTRIBUTE_KEY") != null) {
                style.removeAttribute("FONT_ATTRIBUTE_KEY");
            }
        }
    }
    
    private void updateCSS(Font font, Color fg) {
        JTextComponent component = this.getComponent();
        Document document = component.getDocument();
        if ((document instanceof HTMLDocument)) {
            BasicEditorPaneUI.StyleSheetUIResource ss = new BasicEditorPaneUI.StyleSheetUIResource();
            StyleSheet styleSheet = ((HTMLDocument)document).getStyleSheet();
            StyleSheet[] styleSheets = styleSheet.getStyleSheets();
            if (styleSheets != null) {
                for (StyleSheet ss2 : styleSheets) {
                    if ((ss2 instanceof BasicEditorPaneUI.StyleSheetUIResource)) {
                        styleSheet.removeStyleSheet(ss2);
                    }
                }
            }
            ss.addRule(SwingUtilities2.displayPropertiesToCSS(font, fg));
            styleSheet.addStyleSheet(ss);
            styleSheet.addRule("BASE_SIZE " + component.getFont().getSize());
            Style style = ((StyledDocument)document).getStyle("default");
            if (!font.equals(style.getAttribute("FONT_ATTRIBUTE_KEY"))) {
                style.addAttribute("FONT_ATTRIBUTE_KEY", font);
            }
        }
    }
    
    private void updateStyle(Font font, Color color) {
        this.updateFont(font);
        this.updateForeground(color);
    }
    
    private void updateForeground(Color fg) {
        Style style = ((StyledDocument)this.getComponent().getDocument()).getStyle("default");
        if (style == null) {
            return;
        }
        if (fg == null) {
            if (style.getAttribute(StyleConstants.Foreground) != null) {
                style.removeAttribute(StyleConstants.Foreground);
            }
        }
        else if (!fg.equals(StyleConstants.getForeground(style))) {
            StyleConstants.setForeground(style, fg);
        }
        return;
    }
    
    private void updateFont(Font font) {
        Style style = ((StyledDocument)this.getComponent().getDocument()).getStyle("default");
        if (style == null) {
            return;
        }
        String anObject = (String)style.getAttribute(StyleConstants.FontFamily);
        Integer n = (Integer)style.getAttribute(StyleConstants.FontSize);
        Boolean b = (Boolean)style.getAttribute(StyleConstants.Bold);
        Boolean b2 = (Boolean)style.getAttribute(StyleConstants.Italic);
        Font obj = (Font)style.getAttribute("FONT_ATTRIBUTE_KEY");
        if (font == null) {
            if (anObject != null) {
                style.removeAttribute(StyleConstants.FontFamily);
            }
            if (n != null) {
                style.removeAttribute(StyleConstants.FontSize);
            }
            if (b != null) {
                style.removeAttribute(StyleConstants.Bold);
            }
            if (b2 != null) {
                style.removeAttribute(StyleConstants.Italic);
            }
            if (obj != null) {
                style.removeAttribute("FONT_ATTRIBUTE_KEY");
            }
        }
        else {
            if (!font.getName().equals(anObject)) {
                StyleConstants.setFontFamily(style, font.getName());
            }
            if (n == null || (int)n != font.getSize()) {
                StyleConstants.setFontSize(style, font.getSize());
            }
            if (b == null || (boolean)b != font.isBold()) {
                StyleConstants.setBold(style, font.isBold());
            }
            if (b2 == null || (boolean)b2 != font.isItalic()) {
                StyleConstants.setItalic(style, font.isItalic());
            }
            if (!font.equals(obj)) {
                style.addAttribute("FONT_ATTRIBUTE_KEY", font);
            }
        }
        return;
    }
    
    static class StyleSheetUIResource extends StyleSheet implements UIResource
    {
    }
}
